@@ -244,6 +244,16 @@ class DatabaseTable:
         """Filter the table and return the results on an open session"""
         return cls.query().filter(*args, **kwargs)
 
+    @classmethod
+    def filter_many(cls, field, values):
+        """Filter based on a list of valid values"""
+        results = []
+        for value in values:
+            result = cls.filter(field == value).all()
+            results.extend(result)
+
+        return results
+
     @classmethod
     def tagged(cls, *tag_list):
         """
